package com.tcctlo.law.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.entity.CaseInformation;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.tcctlo.law.vo.CaseInformationListVO;
import com.tcctlo.law.vo.IndexLawInfo;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 案件信息表 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface CaseInformationMapper extends BaseMapper<CaseInformation> {

    /**
     *  首页统计律师信息--查询所有律师信息
     * @return 所有律师信息
     */
    List<IndexLawInfo> selectLawInfo();

    /**
     * 分页条件查询
     *
     * @param page      分页对象
     * @param condition 条件参数
     * @return 结果集
     */
    Page<CaseInformationListVO> selectCondition(@Param("page") Page<CaseInformationListVO> page, @Param("condition") Map<String, Object> condition);

    /**
     * 修改案件收款状态
     * @param caseId    案件ID
     * @return 结果集
     */
    int updateCollectionStatus(@Param("caseId") Long caseId, @Param("collectionStatus") Integer collectionStatus);

    /**
     * 修改案件审核状态
     *
     * @param caseId      案件Id
     * @param auditStatus 审核状态吗
     * @return 结果集
     */
    int updateAuditStatusInt(@Param("caseId") Long caseId, @Param("auditStatus") Integer auditStatus);

    /**
     * @param caseId         案件ID
     * @param amountReceived 收款金额
     * @return 结果集
     */
    int updateCaseAmount(@Param("caseId") Long caseId, @Param("amountReceived") BigDecimal amountReceived);

    /**
     * 根据案件ID查询案件信息
     *
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformationListVO selectCaseById(@Param("id") Long id);




    /**
     * 案件归档
     *
     * @param caseId 要归档的案件ID
     * @return 受影响记录数
     */
    int caseArchived(@Param("caseId") Long caseId);

    /**
     * 批量逻辑删除案件信息
     *
     * @param longList 案件ID集合
     */
    int removeByIds(@Param("ids") List<Long> longList);

    /**
     * 判断案件是否有相关文件
     *
     * @param id 案件id
     * @return 结果集
     */
    int selectCaseFileNum(@Param("id") Long id);

    /**
     * 根据案件ID查询案件信息
     *
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformation selectCaseInfoById(@Param("id") Long id);

    /**
     * 案件审核
     *
     * @param params 参数
     * @return 是否审核成功
     */
    boolean caseReview(@Param("params") Map<String, Object> params);

    /**
     * 案件撤销
     *
     * @param params 参数
     * @return 是否撤销成功
     */
    Boolean claimWithdrawal(@Param("params") Map<String, Object> params);

    /**
     * 案件结案
     *
     * @param params 参数
     * @return 结案结果
     */
    Boolean caseClosed(@Param("params") Map<String, Object> params);

    /**
     * 根据业务类型查询案件数量
     *
     * @param type 业务类型
     * @return 结果集
     */
    Integer selectCountByBusinessType(@Param("userId") String userId,
                                      @Param("type") Integer type,
                                      @Param("startTime") Date startTime,
                                      @Param("endTime") Date endTime);

    /**
     * 利冲统计
     *
     * @param caseStatus 收案状态
     * @return 结果集
     */
    Integer conflictStatistics(@Param("userId") String userId,
                               @Param("caseStatus") Integer caseStatus,
                               @Param("startTime") Date startTime,
                               @Param("endTime") Date endTime);

    /**
     * 未收款统计
     *
     * @return 结果集
     */
    Integer outstandingPayment(@Param("userId") String userId,
                               @Param("startTime") Date startTime,
                               @Param("endTime") Date endTime);

    /**
     * 部分收费统计
     *
     * @return 结果集
     */
    Integer partialCharge(@Param("userId") String userId,
                          @Param("startTime") Date startTime,
                          @Param("endTime") Date endTime);

    /**
     * 逾期未收费
     *
     * @return 结果集
     */
    Integer overdue(@Param("userId") String userId,
                    @Param("startTime") Date startTime,
                    @Param("endTime") Date endTime);


    /**
     * 修改案件涉及律师
     *
     * @param id  案件ID
     * @param ids 涉及律师IDS
     * @return 结果集
     */
    Integer updateLawyerIds(@Param("caseId") Long caseId, @Param("lawIds") String lawIds);


    /**
     * 根据用户ID和案件状态统计案件数量
     *
     * @param userId     用户ID
     * @param caseStatus 案件状态
     * @return 结果集
     */
    Integer statisticsCaseStatus(@Param("userId") String userId, @Param("caseStatus") Integer caseStatus, @Param("businessType") Integer businessType);

    /**
     * 根据用户ID和收款状态统计案件数量
     *
     * @param userId           用户ID
     * @param collectionStatus 收款状态
     * @return 结果集
     */
    Integer statisticsCaseCollectionStatus(@Param("userId") String userId, @Param("collectionStatus") Integer collectionStatus, @Param("businessType") Integer businessType);

    /**
     * 根据用户ID和收款状态统计案件数量
     *
     * @param userId           用户ID
     * @param impulseStatus 收款状态
     * @return 结果集
     */
    Integer statisticsCaseImpulseStatus(@Param("userId") String userId, @Param("impulseStatus") Integer impulseStatus, @Param("businessType") Integer businessType);

    /**
     * 根据用户ID和审核状态统计案件数量
     *
     * @param userId      用户ID
     * @param auditStatus 审核状态
     * @return 结果集
     */
    Integer statisticsCaseAuditStatus(@Param("userId") String userId, @Param("auditStatus") Integer auditStatus, @Param("businessType") Integer businessType);

    /**
     * 根据用户ID和归档状态统计案件数量
     *
     * @param userId        用户ID
     * @param archiveStatus 归档状态
     * @return 结果集
     */
    Integer statisticsCaseArchiveStatus(@Param("userId") String userId, @Param("archiveStatus") Integer archiveStatus, @Param("businessType") Integer businessType);

    /**
     * 根据用户ID和结案状态统计案件数量
     *
     * @param userId       用户ID
     * @param finishStatus 结案状态
     * @return 结果集
     */
    Integer statisticsCaseFinishStatus(@Param("userId") String userId, @Param("finishStatus") Integer finishStatus, @Param("businessType") Integer businessType);

    /**
     * 首页-统计律师涉及案件数量
     * @param lawId 律师ID
     * @return 结果集
     */
    Integer selectLawCaseCount(@Param("lawId") Long lawId);

    /**
     * 首页-统计律师涉及案件金额总计
     * @param lawId 律师ID
     * @return 结果集
     */
    BigDecimal selectLawCaseMoneyCount(@Param("lawId") Long lawId);
}
